#include <iostream>
#include <fstream>
#include <vector>
#include <string>
#include <algorithm>
#include <cstdarg>
#include <cassert>
using namespace std;


typedef unsigned long long u64;

const char iname[] = "subsecvente.in";
const char oname[] = "subsecvente.out";
const int max_length = 3005;
const u64 hash_size = 666013;

vector <int> dp;  u64 dp_base;
int dp2[max_length][max_length];

vector < string > strs;
vector < pair < u64, int > > hash[hash_size];  int hash_obj_index;


void read_in(vector <string> &strs) {
    ifstream fin(iname);
    int n;  fin >> n;
    for (string str; fin >> str; )
        strs.push_back(str);
    fin.close();
    assert(n == (int)strs.size());
}

void write_out(int length) {
    ofstream out(oname);
    out << length << "\n";
    out.close();
}

inline u64 find_value(u64 value) {
    u64 list = value % hash_size;
    vector < pair < u64, int > >::iterator it;

    for (it = hash[list].begin(); it != hash[list].end(); ++ it) 
        if (it->first == value)
            return it->second;
    return 0;
}

inline int hash_array(vector <int>& array) {
    u64 value = 0;

    for (size_t i = 0; i < array.size(); ++ i)
        value = value * dp_base + array[i];

    int index = find_value(value);
    if (!index) {
        index = (++ hash_obj_index);
        hash[value % hash_size].push_back(make_pair(value, index));
    }
    return index;
}

int call_dp(vector <int> array);

int dp_func(int num, ...) {
    // Parse arguments.
    va_list args_list;
    va_start(args_list, num);

    vector <int> args(num);
    for (size_t i = 0; i < args.size(); ++ i) {
        args[i] = va_arg(args_list, int);
    }
    va_end(args_list);

    // Get current state from args list.
    int curr_state = hash_array(args);

    if (dp[curr_state] == -1) {
        // Call all other states.
        for (size_t i = 0; i < args.size(); ++ i) if (args[i] > 0) {
            args[i] -= 1;
            call_dp(args);
            args[i] += 1;
        }
        // Apply dynamic programming.
        bool eq = true;
        bool gtz = args[0] > 0;
        for (size_t i = 1; i < args.size(); ++ i) {
            eq = eq & strs[i][ args[i] ] == strs[i - 1][ args[i - 1] ];
            gtz = gtz & (args[i] > 0);
        }
        if (gtz && eq) {
            for (size_t i = 0; i < args.size(); ++ i) {
                args[i] -= 1;
            }
            dp[curr_state] = max(dp[curr_state], call_dp(args) + 1);
        }
        if (dp[curr_state] == -1)
            dp[curr_state] = eq ? 1 : 0;
    }

    return dp[curr_state];
}

int call_dp(vector <int> array) {
    if (array.size() == 2)
        return dp_func(2, array[0], array[1]);
    if (array.size() == 3)
        return dp_func(3, array[0], array[1], array[2]);
    if (array.size() == 4)
        return dp_func(4, array[0], array[1], array[2], array[3]);
    if (array.size() == 5)
        return dp_func(4, array[0], array[1], array[2], array[3], array[4]);
}

int call_2dim_dp(void) {
    int ans = 0;

    dp2[0][0] = 1;
    for (size_t i = 0; i < strs[0].size(); ++ i) {
        for (size_t j = 0; j < strs[1].size(); ++ j) {
           if (strs[0][i] == strs[1][j]) {
                dp2[i + 1][j + 1] = max(dp2[i + 1][j + 1], dp2[i][j] + 1);
                ans = max(ans, dp2[i + 1][j + 1]);
            } else {
                dp2[i + 1][j + 1] = 0;
            }
        }
    }
    return ans;
}

int main(void) {
    read_in(strs);

    if (strs.size() > 2) {
        // Build dp matrix.
        vector <int> dp_indexes; u64 dp_size = 1;
        for (size_t i = 0; i < strs.size(); ++ i) {
            dp_size *= strs[i].size();
            dp_base = max(dp_base, (u64)strs[i].size() + 1);
            dp_indexes.push_back((int) strs[i].size() - 1);
        }
        dp.resize(dp_size + 5);
        dp.assign(dp.size(), -1);
        // Apply dynamic programming.
        call_dp(dp_indexes);
        // Get answer.
        int ans = 0;
        for (int i = 1; i <= hash_obj_index; ++ i)
            ans = max(ans, dp[i]);

        write_out(ans);
    } else {
        write_out(call_2dim_dp());
    }
    return 0;
}